if [ -f /etc/pulse/client.conf ] && cmp -s /etc/defaults/etc/pulse/client.conf /etc/pulse/client.conf
then
    rm /etc/pulse/client.conf
fi

if [ -f /etc/pulse/daemon.conf ] && cmp -s /etc/defaults/etc/pulse/daemon.conf /etc/pulse/daemon.conf
then
    rm /etc/pulse/daemon.conf
fi

if [ -f /etc/pulse/default.pa ] && cmp -s /etc/defaults/etc/pulse/default.pa /etc/pulse/default.pa
then
    rm /etc/pulse/default.pa
fi

if [ -f /etc/pulse/system.pa ] && cmp -s /etc/defaults/etc/pulse/system.pa /etc/pulse/system.pa
then
    rm /etc/pulse/system.pa
fi

