if [ ! -e /etc/pulse/client.conf ]
then
    /usr/bin/mkdir -p /etc/pulse
    /usr/bin/cp /etc/defaults/etc/pulse/client.conf /etc/pulse/client.conf
fi

if [ ! -e /etc/pulse/daemon.conf ]
then
    /usr/bin/mkdir -p /etc/pulse
    /usr/bin/cp /etc/defaults/etc/pulse/daemon.conf /etc/pulse/daemon.conf
fi

if [ ! -e /etc/pulse/default.pa ]
then
    /usr/bin/mkdir -p /etc/pulse
    /usr/bin/cp /etc/defaults/etc/pulse/default.pa /etc/pulse/default.pa
fi

if [ ! -e /etc/pulse/system.pa ]
then
    /usr/bin/mkdir -p /etc/pulse
    /usr/bin/cp /etc/defaults/etc/pulse/system.pa /etc/pulse/system.pa
fi

